C0ProblemSourcePin class final

One immutable prose-source pin carried by the generated C0 projection.

Constructors

C0ProblemSourcePin({required String path, required String sha256, String? note})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
note String?
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sha256 String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited