ProblemMatcherError class final
Thrown by expectProblem when an assertion fails.
Extends AssertionError so any test framework reports it as a failure.
- Inheritance
-
- Object
- Error
- AssertionError
- ProblemMatcherError
Constructors
- ProblemMatcherError(Object? message)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → Object?
-
Message describing the assertion error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point where this error was first thrown.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited